# This define installs a package from S3 over *HTTPS*
# take it into account if you have ACL's protecting your S3 bucket
# If it is the case you'd better use define profile_s3::manage + Package type

define s3::install (

  String            $package              = $title,
  String            $source               = '',
  String            $ensure               = 'present',
  String            $s3_domain            = 's3.amazonaws.com',
  String            $provider             = 'rpm',
  Optional[String]  $vendor               = undef,
  Optional[String]  $root                 = undef,
  Optional[String]  $status               = undef,
  Optional[String]  $adminfile            = undef,
  Optional[String]  $category             = undef,
  Optional[String]  $configfiles          = undef,
  Optional[String]  $description          = undef,
  Optional[String]  $flavor               = undef,
  Optional[String]  $instance             = undef,
  Optional[String]  $platform             = undef,
  Optional[String]  $responsefile         = undef,
  Optional[Boolean] $reinstall_on_refresh = undef,
  Optional[Boolean] $allow_virtual        = undef,
  Optional[Boolean] $allowcdrom           = undef,
  Optional[Array]   $uninstall_options    = undef,
  Optional[Array]   $install_options      = undef,
  Optional[Hash]    $package_settings     = undef,


){

  $valid_ensures = [ 'absent', 'present']
  validate_re($ensure, $valid_ensures)
  $real_source = "https://${s3_domain}/${source}"

  package { $package:
    ensure               => $ensure,
    provider             => $provider,
    source               => $real_source,
    vendor               => $vendor,
    root                 => $root,
    status               => $status,
    adminfile            => $adminfile,
    category             => $category,
    configfiles          => $configfiles,
    description          => $description,
    flavor               => $flavor,
    instance             => $instance,
    platform             => $platform,
    responsefile         => $responsefile,
    reinstall_on_refresh => $reinstall_on_refresh,
    allow_virtual        => $allow_virtual,
    allowcdrom           => $allowcdrom,
    uninstall_options    => $uninstall_options,
    install_options      => $install_options,
    package_settings     => $package_settings,
  }
}
