require 'spec_helper'
require 'shared_contexts'

describe 's3::manage' do
  # by default the hiera integration uses hiera data from the shared_contexts.rb file
  # but basically to mock hiera you first need to add a key/value pair
  # to the specific context in the spec/shared_contexts.rb file
  # Note: you can only use a single hiera context per describe/context block
  # rspec-puppet does not allow you to swap out hiera data on a per test block
  #include_context :hiera

  let(:title) { 'XXreplace_meXX' }

  # below is the facts hash that gives you the ability to mock
  # facts on a per describe/context block.  If you use a fact in your
  # manifest you should mock the facts below.
  let(:facts) do
    {}
  end

  # below is a list of the resource parameters that you can override.
  # By default all non-required parameters are commented out,
  # while all required parameters will require you to add a value
  let(:params) do
    {
      #:destination => "",
      #:bucket => "",
      #:source => :undef,
      #:command => "cpbl",
      #:flag => "",
      #:refreshonly => true,
      #:path => ["/usr/local/sbin", "/usr/local/bin", "/sbin:/bin", "/usr/sbin", "/usr/bin", "/opt/aws/bin", "/root/bin"],

    }
  end
  # add these two lines in a single test block to enable puppet and hiera debug mode
  # Puppet::Util::Log.level = :debug
  # Puppet::Util::Log.newdestination(:console)
  
  it do
    is_expected.to contain_exec("$title")
        .with({
          "path" => ["/usr/local/sbin", "/usr/local/bin", "/sbin:/bin", "/usr/sbin", "/usr/bin", "/opt/aws/bin", "/root/bin"],
          "command" => "aws s3 cp s3://undef  ",
          "unless" => "/bin/ls undef",
          })
  end
    
  it do
    is_expected.to contain_exec("$title")
        .with({
          "path" => ["/usr/local/sbin", "/usr/local/bin", "/sbin:/bin", "/usr/sbin", "/usr/bin", "/opt/aws/bin", "/root/bin"],
          "command" => "aws s3 cp undef s3:// ",
          "refreshonly" => true,
          })
  end
    
  it do
    is_expected.to contain_exec("$title")
        .with({
          "path" => ["/usr/local/sbin", "/usr/local/bin", "/sbin:/bin", "/usr/sbin", "/usr/bin", "/opt/aws/bin", "/root/bin"],
          "command" => "aws s3 cp s3://undef s3:// ",
          "refreshonly" => true,
          })
  end
    
  it do
    is_expected.to contain_exec("$title")
        .with({
          "path" => ["/usr/local/sbin", "/usr/local/bin", "/sbin:/bin", "/usr/sbin", "/usr/bin", "/opt/aws/bin", "/root/bin"],
          "command" => "aws s3 mv s3://undef  ",
          "unless" => "/bin/ls undef",
          })
  end
    
  it do
    is_expected.to contain_exec("$title")
        .with({
          "path" => ["/usr/local/sbin", "/usr/local/bin", "/sbin:/bin", "/usr/sbin", "/usr/bin", "/opt/aws/bin", "/root/bin"],
          "command" => "aws s3 mv undef s3:// ",
          "refreshonly" => true,
          })
  end
    
  it do
    is_expected.to contain_exec("$title")
        .with({
          "path" => ["/usr/local/sbin", "/usr/local/bin", "/sbin:/bin", "/usr/sbin", "/usr/bin", "/opt/aws/bin", "/root/bin"],
          "command" => "aws s3 mv s3://undef s3:// ",
          "refreshonly" => true,
          })
  end
    
  it do
    is_expected.to contain_exec("$title")
        .with({
          "path" => ["/usr/local/sbin", "/usr/local/bin", "/sbin:/bin", "/usr/sbin", "/usr/bin", "/opt/aws/bin", "/root/bin"],
          "command" => "aws s3 sync s3://undef  ",
          "refreshonly" => true,
          })
  end
    
  it do
    is_expected.to contain_exec("$title")
        .with({
          "path" => ["/usr/local/sbin", "/usr/local/bin", "/sbin:/bin", "/usr/sbin", "/usr/bin", "/opt/aws/bin", "/root/bin"],
          "command" => "aws s3 sync undef s3:// ",
          "refreshonly" => true,
          })
  end
    
  it do
    is_expected.to contain_exec("$title")
        .with({
          "path" => ["/usr/local/sbin", "/usr/local/bin", "/sbin:/bin", "/usr/sbin", "/usr/bin", "/opt/aws/bin", "/root/bin"],
          "command" => "aws s3 sync s3://undef s3:// ",
          "refreshonly" => true,
          })
  end
    
  it do
    is_expected.to contain_exec("$title")
        .with({
          "path" => ["/usr/local/sbin", "/usr/local/bin", "/sbin:/bin", "/usr/sbin", "/usr/bin", "/opt/aws/bin", "/root/bin"],
          "command" => "aws s3 rm s3://undef ",
          })
  end
    
  it do
    is_expected.to contain_notify("error")
        .with({
          "message" => "The command entered is incorrect",
          })
  end
    
end
